@@ -14,8 +14,8 @@
 #include "config.h"
 #endif
 
-#define SASS_VERSION "0.5.14"
-#define SASS_FLAVOR  "Sassyphpras"
+#define SASS_VERSION "0.5.16"
+#define SASS_FLAVOR "Sassyphpras"
 
 #include <php.h>
 #include <ext/standard/info.h>
@@ -23,12 +23,25 @@
 #include <Zend/zend_exceptions.h>
 
 #include <sass.h>
+#include <sass2scss.h>
 
 zend_class_entry *sass_ce;
 zend_class_entry *sass_exception_ce;
 
 zend_class_entry *sass_get_exception_base();
 
+#ifdef PHP_WIN32
+#define PHP_SASS_API __declspec(dllexport)
+#elif defined(__GNUC__) && __GNUC__ >= 4
+#define PHP_SASS_API __attribute__((visibility("default")))
+#else
+#define PHP_SASS_API
+#endif
+
+#ifdef ZTS
+#include "TSRM.h"
+#endif
+
 PHP_METHOD(Sass, __construct);
 PHP_METHOD(Sass, compile);
 PHP_METHOD(Sass, compileFile);
